lilypondfiletools.NonattributedBlock
====================================

.. abjad-lineage:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock

.. autoclass:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.append
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.count
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.extend
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.index
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.insert
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.is_formatted_when_empty
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.pop
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.remove
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.reverse
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.sort
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__add__
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__contains__
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__delitem__
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__delslice__
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__eq__
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__format__
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__ge__
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__getitem__
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__getslice__
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__gt__
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__iadd__
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__imul__
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__iter__
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__le__
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__len__
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__lt__
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__mul__
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__ne__
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__repr__
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__reversed__
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__rmul__
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__setitem__
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__setslice__

Bases
-----

- :py:class:`__builtin__.list <list>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read/write properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.is_formatted_when_empty
   :noindex:

Methods
-------

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.append
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.count
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.extend
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.index
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.insert
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.pop
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.remove
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.reverse
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.sort
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__add__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__contains__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__delitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__delslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__ge__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__getitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__getslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__gt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__iadd__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__imul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__iter__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__le__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__len__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__lt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__mul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__repr__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__reversed__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__rmul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__setitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.__setslice__
   :noindex:
